@@ -8,7 +8,7 @@ use List::Util ();
 use SVG::Sparkline::Utils;
 
 use 5.008000;
-our $VERSION = 0.36;
+our $VERSION = 1.10;
 
 # alias to make calling shorter.
 *_f = *SVG::Sparkline::Utils::format_f;
@@ -25,7 +25,9 @@ sub make
     my $vals = SVG::Sparkline::Utils::summarize_values( $args->{values} );
 
     my $height = $args->{height} - 2*$args->{pady};
-    my $yscale = -$height / $vals->{range};
+    # If we get all zeros for data, the range will be 0, and the division will
+    # fail. Almost anything will be a reasonable range, so arbitrarily choose 1.
+    my $yscale = -$height / ($vals->{range} || 1);
     my $baseline = _f(-$yscale*$vals->{min});
 
     # Figure out the width I want and define the viewBox
@@ -149,7 +151,7 @@ SVG::Sparkline::Bar - Supports SVG::Sparkline for bar graphs.
 
 =head1 VERSION
 
-This document describes SVG::Sparkline::Bar version 0.36
+This document describes SVG::Sparkline::Bar version 1.10
 
 =head1 DESCRIPTION
 
@@ -203,11 +205,11 @@ No bugs have been reported.
 
 =head1 AUTHOR
 
-G. Wade Johnson  C<< wade@anomaly.org >>
+G. Wade Johnson  C<< gwadej@cpan.org >>
 
 =head1 LICENCE AND COPYRIGHT
 
-Copyright (c) 2012, G. Wade Johnson C<< wade@anomaly.org >>. All rights reserved.
+Copyright (c) 2013, G. Wade Johnson C<< gwadej@cpan.org >>. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl 5.8.0. See L<perlartistic>.
